"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deployCli = exports.deployLambda = void 0;
const infra_aws_1 = require("@goldstack/infra-aws");
const infra_1 = require("@goldstack/infra");
const archiver_1 = __importDefault(require("archiver"));
const fs_1 = __importDefault(require("fs"));
const utils_aws_cli_1 = require("@goldstack/utils-aws-cli");
const deployLambda = async (params) => {
    const targetArchive = 'lambda.zip';
    const lambdaDistDir = './distLambda';
    await new Promise((resolve, reject) => {
        const output = fs_1.default.createWriteStream(targetArchive);
        const archive = archiver_1.default('zip', {
            zlib: { level: 9 },
        });
        archive.on('warning', function (err) {
            console.warn(err.message);
        });
        output.on('finish', () => {
            resolve();
        });
        output.on('error', reject);
        archive.pipe(output);
        archive.directory(lambdaDistDir, false, {
            // mode required for languages that are packaged into executables, e.g. Go
            mode: 511, //  511 === 0777; 493 === 0755; 438 === 0666; 420 === 0644
        });
        archive.finalize();
    });
    utils_aws_cli_1.awsCli({
        credentials: await infra_aws_1.getAWSUser(params.deployment.awsUser),
        region: params.deployment.awsRegion,
        command: `lambda update-function-code --function-name ${infra_1.readTerraformStateVariable(params.deploymentState, 'lambda_function_name')} --zip-file fileb://${targetArchive}`,
    });
};
exports.deployLambda = deployLambda;
const deployCli = async (deployment) => {
    const deploymentState = infra_1.readDeploymentState('./', deployment.name);
    await exports.deployLambda({
        deployment,
        deploymentState,
    });
};
exports.deployCli = deployCli;
//# sourceMappingURL=templateLambdaExpressDeploy.js.map